@@ -26,7 +26,6 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s stoppede deling af mappen \"%2$s\" med dig",
     "Someone unshared folder \"%s\" with you" : "En person stoppede deling af mappen \"%s\" med dig",
     "No file provided for import" : "Ingen fil til import",
-    "Unsupported file type for import" : "Denne filtype er ikke understøttet til import",
     "Bookmarks shared by %s" : "Bogmærker delt af %s",
     "Frequent bookmarks" : "Hyppige bogmærker",
     "Recent bookmarks" : "Seneste bogmærker",
@@ -63,8 +62,6 @@ OC.L10N.register(
     "Cancel selection" : "Annuller valg",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valgte {folders} mapper og {bookmarks} bogmærker",
     "Do you really want to delete these items?" : "Vil du virkelig slette disse elementer?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valgt %n bogmærke","Valgt %n bogmærker"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Valgte %n mappe","Valgte %n mapper"],
     "Go back" : "Gå tilbage",
     "Share folder" : "Del mappe",
     "Select one or more tags" : "Vælg et eller flere tags",
@@ -84,13 +81,10 @@ OC.L10N.register(
     "Sort by manual order" : "Sorter efter manuel rækkefølge",
     "Sort by URL" : "Sorter efter URL",
     "RSS feed copied" : "RSS-feed kopieret",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Tilføjelse af %n bogmærke til ny mappe","Tilføjelse af %n bogmærker til ny mappe"],
     "Enter a link" : "Indtast et link",
     "Enter a title" : "Indtast en titel",
     "No bookmarks found" : "Ingen bogmærker fundet",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} mapper og {bookmarks} bogmærker",
-    "_%n bookmark_::_%n bookmarks_" : ["%n bogmærke","%n bogmærker"],
-    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
     "Welcome to Bookmarks" : "Velkommen til Bogmærker",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Denne app giver dig mulighed for at administrere links til dine yndlingssteder på nettet. Sorter dine bogmærker i mapper, mærk dem med tags og del dem med andre! Appen vil regelmæssigt tjekke alle dine links for tilgængelighed og vise utilgængelige links. Hvis du tilføjer et link til en fil på nettet, vil filen automatisk blive downloadet til dine Nextcloud-filer. Du kan også importere bogmærker eksporteret fra andre tjenester eller direkte synkronisere bogmærker fra alle dine browsere med denne app.",
     "Add a bookmark" : "Tilføj et bogmærke",
@@ -109,9 +103,6 @@ OC.L10N.register(
     "Importing bookmarks" : "Importerer bogmærker",
     "Moving selection" : "Flytter valgte",
     "Adding selection to folders" : "Tilføjelse af valg til mapper",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flytter %n mappe og nogle bogmærker","Flytter %n mapper og nogle bogmærker"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Flytter %n mappe","Flytter %n mapper"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flytter %n bogmærke","Flytter %n bogmærker"],
     "All bookmarks" : "Alle bogmærker",
     "Recent" : "Seneste",
     "Shared with you" : "Shared with you",
@@ -123,7 +114,6 @@ OC.L10N.register(
     "Delete" : "Slet",
     "Untagged" : "Fravalgt",
     "{used} bookmarks of {available} available" : "{used} bogmærker af {available} tilgængelige",
-    "Settings" : "Indstillinger",
     "No bookmarked files" : "Ingen bogmærkede filer",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bogmærker til filer som fotos eller PDF'er gemmes automatisk i dine Nextcloud-filer, så du stadig kan finde dem, selv når linket går offline.",
     "No broken links" : "Ingen ødelagte links",
@@ -132,6 +122,7 @@ OC.L10N.register(
     "No bookmarks here" : "Ingen bogmærker her",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Tilføj bogmærker manuelt eller importer bogmærker fra en HTML-fil.",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Indtast stien til en mappe i dine filer, hvor bogmærkede filer skal gemmes.",
+    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Bogmærkeapp'en kan automatisk tage backup af dine bogmærker på en daglig basis, for at forhindre datatab når der synkroniseres bogmærker på tværs af apparater.",
     "Enter the path of a folder in your Files where backups will be stored." : "Indtast stien til en mappe i dine filer, hvor sikkerhedskopier vil blive gemt.",
     "Client apps" : "Klient apps",
     "Also check out the collection of client apps that integrate with this app: " : "Tjek også samlingen af klientapps, der integreres med denne app:",
