@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Bókamerki",
     "No file provided for import" : "Engin skrá valin til innflutnings",
-    "Unsupported file type for import" : "Ekki er hægt að flytja inn þessa tegund af bókamerki",
     "Bookmarks shared by %s" : "Bókamerki deilt af %s",
     "Select bookmark" : "Veldu bókamerki",
     "Details" : "Nánar",
@@ -17,8 +16,6 @@ OC.L10N.register(
     "Select all" : "Select all",
     "Cancel selection" : "Hætta við val",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valdi %n bókamerki","Valdi %n bókamerki"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Valin %n mappa","Valdar %n möppur"],
     "Go back" : "Fara til baka",
     "Select one or more tags" : "Veldu eitt eða fleiri merki",
     "New" : "Nýtt",
@@ -37,9 +34,6 @@ OC.L10N.register(
     "Choose folder" : "Veldu möppu",
     "Submit" : "Senda inn",
     "Cancel" : "Hætta við",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Færi %n möppu og einhver bókamerki","Færi %n möppur og einhver bókamerki"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Færi %n möppu","Færi %n möppur"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Færi %n bókamerki","Færi %n bókamerki"],
     "All bookmarks" : "Öll bókamerki",
     "Recent" : "Nýlegt",
     "Shared with you" : "Deilt með þér",
@@ -47,7 +41,6 @@ OC.L10N.register(
     "Delete" : "Eyða",
     "Untagged" : "Ómerkt",
     "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
-    "Settings" : "Stillingar",
     "No bookmarks here" : "Engin bókamerki hér",
     "Client apps" : "Biðlaraforrit",
     "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
