@@ -26,7 +26,7 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s heeft zijn map \"%2$s\" niet meer met jou gedeeld",
     "Someone unshared folder \"%s\" with you" : "Iemand heeft zijn map \"%s\" niet meer met jou gedeeld",
     "No file provided for import" : "Geen bestand aangeboden om te importeren",
-    "Unsupported file type for import" : "Bestandstype wordt niet ondersteund voor importeren",
+    "Failed to upload file" : "Kon bestand niet uploaden",
     "Bookmarks shared by %s" : "Bookmarks gedeeld door %s",
     "Frequent bookmarks" : "frequente bookmarks",
     "Recent bookmarks" : "Recente bookmarks",
@@ -57,8 +57,6 @@ OC.L10N.register(
     "Cancel selection" : "Annuleren selectie",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Geselecteerde {folders} mappen en {bookmarks} bookmarks",
     "Do you really want to delete these items?" : "Wil je deze objecten echt verwijderen?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Geselecteerde %n bladwijzer","Geselecteerde %n bookmarks"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Selecteerde %n map","Selecteerde %n mappen"],
     "Go back" : "Ga terug",
     "Share folder" : "Delen map",
     "Select one or more tags" : "Kies één of meer tags",
@@ -77,13 +75,10 @@ OC.L10N.register(
     "Sort by click count" : "Sorteren op aantal doorkliks",
     "Sort by manual order" : "Sorteer op handmatige volgorde.",
     "RSS feed copied" : "RSS Feed gekopieerd",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Voeg %n bladwijzers toe aan nieuwe map","Voeg %n bladwijzers toe aan nieuwe map"],
     "Enter a link" : "Voer een link in",
     "Enter a title" : "Voer een titel in",
     "No bookmarks found" : "Geen bladwijzers gevonden",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} mappen en {bookmarks} bladwijzers",
-    "_%n bookmark_::_%n bookmarks_" : ["%n bladwijzer","%n bladwijzers"],
-    "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
     "Add a bookmark" : "Voeg een bladwijzer toe",
     "Import bookmarks" : "Importeer bladwijzers",
     "Sync with your browser" : "Sync met je browser",
@@ -100,9 +95,6 @@ OC.L10N.register(
     "Importing bookmarks" : "Bladwijzers importeren",
     "Moving selection" : "Selectie verplaatsen",
     "Adding selection to folders" : "Selectie aan mappen toevoegen",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n folder en bladwijzers verplaatsen","%n mappen en bookmarks verplaatsen"],
-    "_Moving %n folder_::_Moving %n folders_" : ["%n folder verplaatsen","%n mappen verplaatsen"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n bladwijzer verplaatsen","%n bladwijzers verplaatsen"],
     "All bookmarks" : "Alle bladwijzers",
     "Recent" : "Recent",
     "Shared with you" : "Gedeeld met jou",
@@ -114,7 +106,6 @@ OC.L10N.register(
     "Delete" : "Verwijderen",
     "Untagged" : "Niet getagd",
     "{used} bookmarks of {available} available" : "{used} bladwijzers van {available} beschikbare",
-    "Settings" : "Instellingen",
     "No bookmarked files" : "Geen bladwijzers voor bestanden",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bladwijzers naar bestanden zoals foto's of PDF's worden automatisch opgeslagen in je Nextcloud bestanden, zodat je ze nog steeds kunt vinden, zelfs als de link offline gaat.",
     "No duplicated bookmarks" : "Geen duplicaat bladwijzers",
