@@ -26,7 +26,7 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s vam onemogoči souporabo mape »%2$s«",
     "Someone unshared folder \"%s\" with you" : "Nekdo vam onemogoči souporabo mape »%s«",
     "No file provided for import" : "Ni navedenih datotek za uvoz",
-    "Unsupported file type for import" : "Nepodprta vrsta datoteke za uvoz",
+    "Failed to upload file" : "Pošiljanje datoteke je spodletelo",
     "Bookmarks shared by %s" : "Zaznamki v souporabi z %s",
     "Frequent bookmarks" : "Pogosti zaznamki",
     "Recent bookmarks" : "Nedavni zaznamki",
@@ -63,8 +63,6 @@ OC.L10N.register(
     "Cancel selection" : "Prekliči izbor",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Izbrane mape {folders} in zaznamki {bookmarks}",
     "Do you really want to delete these items?" : "Ali ste prepričani, da želite izbrisati te predmete?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Izbran je %n zaznamek","Izbrana sta %n zaznamka","Izbrani so %n zaznamki","Izbranih je %n zaznamkov"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Izbrana je %n mapa","Izbrani sta %n mapi","Izbrane so %n mape","Izbranih je %n map"],
     "Go back" : "Skoči nazaj",
     "Share folder" : "Omogoči souporabo mape",
     "Select one or more tags" : "Izbor enega oziroma več zaznamkov",
@@ -76,6 +74,7 @@ OC.L10N.register(
     "Copy RSS Feed of current view" : "Kopiraj vir RSS trenutnega pogleda",
     "The RSS feed requires authentication with your Nextcloud credentials" : "Vir RSS zahteva overitev z vašimi poverili Nextcloud",
     "Search" : "Poišči",
+    "Empty trash bin" : "Izprazni smeti",
     "Sort by created date" : "Razvrsti po datumu ustvarjanja",
     "Sort by last modified" : "Razvrsti po datumu spremembe",
     "Sort by title" : "Razvrsti po naslovu",
@@ -83,13 +82,10 @@ OC.L10N.register(
     "Sort by manual order" : "Razvrsti ročno",
     "Sort by URL" : "Razvrsti po naslovu URL",
     "RSS feed copied" : "Vir RSS je kopiran",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Dodajanje %n zaznamka v novo mapo","Dodajanje %n zaznamkov v novo mapo","Dodajanje %n zaznamkov v novo mapo","Dodajanje %n zaznamkov v novo mapo"],
     "Enter a link" : "Vnesite povezavo",
     "Enter a title" : "Vpis naslova",
     "No bookmarks found" : "Ni najdenih zaznamkov",
     "{folders} folders and {bookmarks} bookmarks" : "Izbrane mape {folders} in zaznamki {bookmarks}",
-    "_%n bookmark_::_%n bookmarks_" : ["%n zaznamek","%n zaznamka","%n zaznamki","%n zaznamkov"],
-    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n map"],
     "Welcome to Bookmarks" : "Dobrodošli med Zaznamki",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Program omogoča upravljanje povezav priljubljenih spletnih mest. Omogoča razvrščanje zaznamkov v mape, označevanje z oznakami in izmenjavo z drugimi uporabniki! Program samodejno preverja razpoložljivost vpisanih povezav in prikaže nedostopne. Povezave do datotek na spletu sprožijo samodejen prenos v oblak Nextcloud. Prav tako je mogoče uvoziti zaznamke iz drugih storitev in neposredno usklajevanje zaznamkov iz vseh brskalnikov.",
     "Add a bookmark" : "Dodaj zaznamek",
@@ -100,6 +96,7 @@ OC.L10N.register(
     "Shared by {user}" : "V skupni rabi z {user}",
     "Rename folder" : "Preimenuj mapo",
     "Move folder" : "Premakni mapo",
+    "Delete folder permanently" : "Izbriši mapo trajno",
     "Choose folder" : "Izbor mape",
     "Submit" : "Pošlji",
     "Cancel" : "Prekliči",
@@ -108,9 +105,6 @@ OC.L10N.register(
     "Importing bookmarks" : "Uvažanje zaznamkov",
     "Moving selection" : "Premikanje izbora",
     "Adding selection to folders" : "Dodajanje izbire za mape",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Premikanje mape %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Poteka premikanje %n mape","Poteka premikanje %n map","Poteka premikanje %n map","Poteka premikanje %n map"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Poteka premikanje %n zaznamka","Poteka premikanje %n zaznamkov","Poteka premikanje %n zaznamkov","Poteka premikanje %n zaznamkov"],
     "All bookmarks" : "Vsi zaznamki",
     "Recent" : "Nedavne",
     "Shared with you" : "V souporabi z vami",
@@ -122,7 +116,6 @@ OC.L10N.register(
     "Delete" : "Izbriši",
     "Untagged" : "Neoznačeno",
     "{used} bookmarks of {available} available" : "Uporabljeno {used} od razpoložljivih {available}",
-    "Settings" : "Nastavitve",
     "No bookmarked files" : "Ni še dodanih zaznamkov datotek",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Zaznamki do datotek, kot so slike in dokumenti PDF, bodo samodejno shranjeni med datoteke Nextcloud, zato je dostop mogoč tudi pri delu brez povezave.",
     "No broken links" : "Ni okvarjenih povezav",
