@@ -12,7 +12,7 @@ namespace OCA\Bookmarks\Service;
 use OCP\AppFramework\Services\IAppConfig;
 
 class SettingsService {
-	/** @var array<string,string>  */
+	/** @var array<string,string> */
 	public const DEFAULTS = [
 		'previews.screenly.url' => '',
 		'previews.screenly.token' => '',
@@ -25,7 +25,8 @@ class SettingsService {
 	];
 
 	public function __construct(
-		private IAppConfig $config) {
+		private IAppConfig $config,
+	) {
 	}
 
 	/**
@@ -43,7 +44,7 @@ class SettingsService {
 	 */
 	public function setSetting(string $key, string $value): void {
 		if (!array_key_exists($key, self::DEFAULTS)) {
-			throw new \Exception('Unknown settings key '.$key);
+			throw new \Exception('Unknown settings key ' . $key);
 		}
 		$this->config->setAppValue($key, $value);
 	}
